slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDSetUp

Sets up all the internal data structures necessary for the execution of the singular value solver.

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDSetUp(SVD svd)

Collective on svd

### Input Parameter

| svd | - singular value solver context

### Notes

This function need not be called explicitly in most cases, since SVDSolve() calls it. It can be useful when one wants to measure the set-up time separately from the solve time.

### See Also

SVDCreate(), SVDSolve(), SVDDestroy()

### Level

developer

### Location

src/svd/interface/svdsetup.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages